/**
 * GUI Commands
 * Copyright 2004 Andrew Pietsch
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ButtonFactory.java,v 1.8 2005/06/10 08:45:44 pietschy Exp $
 */

package org.pietschy.command;

import javax.swing.*;

/**
 * This interface defines factory methods that all commands use when creating buttons.
 * @see MenuFactory
 * @see ToolbarFactory
 * @see DefaultButtonFactory
 * @see CommandManager#setButtonFactory
 */
public interface
ButtonFactory
{
   /**
    * A factory method for {@link JButton}s.
    * @return A new {@link JButton}.
    */
   public JButton createButton();

   /**
    * A factory method for ToggleButtons.  The {@link DefaultButtonFactory} creates instances of
    * {@link JToggleButton}s.  Other factories may create non-standard implementations but are constrained to
    * ensure that {@link java.awt.event.ItemListener} notifications is consistent
    * with that of {@link javax.swing.JToggleButton}s.
    * @return A new {@link JToggleButton}.
    */
   public AbstractButton createToggleButton();

   /**
    * A factory method for {@link JCheckBox}s.
    * @return A new {@link JCheckBox}.
    */
   public JCheckBox createCheckBox();

   /**
    * A factory method for {@link JRadioButton}s.
    * @return A new {@link JRadioButton}.
    */
   public JRadioButton createRadioButton();
}
